@@ -1,12 +1,12 @@
 package LWP::UserAgent::Patch::HTTPSHardTimeout;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
 no warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use Module::Patch 0.12 qw();
 use base qw(Module::Patch);
@@ -23,7 +23,7 @@ my $p_send_request = sub {
     if ($scheme eq 'https' && $config{-timeout} > 0) {
         my $resp;
         eval {
-            $log->tracef("Wrapping send_request() with alarm timeout (%d)",
+            log_trace("Wrapping send_request() with alarm timeout (%d)",
                          $config{-timeout});
             local $SIG{ALRM} = sub { die "alarm\n" };
             alarm $config{-timeout};
@@ -77,7 +77,7 @@ LWP::UserAgent::Patch::HTTPSHardTimeout - Add hard timeout to HTTPS requests
 
 =head1 VERSION
 
-This document describes version 0.05 of LWP::UserAgent::Patch::HTTPSHardTimeout (from Perl distribution LWP-UserAgent-Patch-HTTPSHardTimeout), released on 2015-08-17.
+This document describes version 0.06 of LWP::UserAgent::Patch::HTTPSHardTimeout (from Perl distribution LWP-UserAgent-Patch-HTTPSHardTimeout), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -97,19 +97,13 @@ Can be used with L<WWW::Mechanize> because it uses L<LWP::UserAgent>.
 By patching, you do not need to replace all the client code which uses
 LWP::UserAgent (or WWW::Mechanize, and so on).
 
-=head1 SEE ALSO
-
-http://stackoverflow.com/questions/9400068/make-timeout-work-for-lwpuseragent-https
-
-L<LWPx::ParanoidAgent>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/LWP-UserAgent-Patch-HTTPSHardTimeout>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-LWP-UserAgent-Patch-HTTPSHardTimeout>.
+Source repository is at L<https://github.com/perlancar/perl-LWP-UserAgent-Patch-HTTPSHardTimeout>.
 
 =head1 BUGS
 
@@ -119,13 +113,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+http://stackoverflow.com/questions/9400068/make-timeout-work-for-lwpuseragent-https
+
+L<LWPx::ParanoidAgent>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
